==> nodegit-0.2.4.tgz: package/src/diff_stats.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/diff_stats.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitDiffStats::GitDiffStats(git_diff_stats *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitDiffStats::~GitDiffStats() {
   }

  void GitDiffStats::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("DiffStats"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("DiffStats"), _constructor_template);
  }

  NAN_METHOD(GitDiffStats::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitDiffStats cannot be instantiated.");
     }

    GitDiffStats* object = new GitDiffStats(static_cast<git_diff_stats *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitDiffStats::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitDiffStats::constructor_template)->NewInstance(2, argv));
  }

  git_diff_stats *GitDiffStats::GetValue() {
    return this->raw;
  }

  git_diff_stats **GitDiffStats::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitDiffStats::constructor_template;

==> nodegit-0.2.5.tgz: package/src/diff_stats.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/diff_stats.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitDiffStats::GitDiffStats(git_diff_stats *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitDiffStats::~GitDiffStats() {
   }

  void GitDiffStats::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("DiffStats"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("DiffStats"), _constructor_template);
  }

  NAN_METHOD(GitDiffStats::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitDiffStats cannot be instantiated.");
     }

    GitDiffStats* object = new GitDiffStats(static_cast<git_diff_stats *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitDiffStats::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitDiffStats::constructor_template)->NewInstance(2, argv));
  }

  git_diff_stats *GitDiffStats::GetValue() {
    return this->raw;
  }

  git_diff_stats **GitDiffStats::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitDiffStats::constructor_template;
